==> ZenTaoPMS.max3.1.php5.4_5.6.zip: zentaopms/extension/biz/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPsySjoTEvGi8hwWY1DqE2R7d+6s8g/YvIj176WKkh5MvJ9XgrPuHrBiopllJPKiLrUCRMyIC
odw9P4TPeF6cMvBGbXBYH9Lc/rfnOaX5DgYVBPkIWuD6uWMfqg2PxuqJCvpf1zfji70E9KoTi2/E
4ogFtXxf1gPlNfLabJuDfrn0ze18mPpVySNdeg6U4XZ156gHA/9iV2tnAzMWGbzTCYbOmXhHQ03g
rk9zc3tqU+Y1pli9kKL1oSB/1QKcIsJJvQ65cdfgfA0sEzbiaJNlxOGNG1mi82jhFXYFWTWlcIKm
xhanqGQ324s+mdv8vsMvclAn6dG6gmUne9V1XIgr4UfWB9Eiwl7IPXf59F6XrxG6h2pwhtEmZxtC
IyAd5uxs5PHTJ8wt8zXtk1jfOMb5nD1N2y/4apqiuUmH8GgsEqn+YcDzmcxCEq2LCGmZpETtol2f
jwI2JxpS1QIZQ/cQLnGsYnOM0WSC4EKY3jLa70ETMsP5hVKU2gq=

==> ZenTaoPMS.max3.4.php5.4_5.6.zip: zentaopms/extension/biz/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPxh1kcBXBXzLH7KlGVeLaPljM88+XijoGj659yD9pGNRFqTA6QJEStb6/7vIWqSvHPdhkIqh
1I/lUngxtlcBHOdH5Ns7kTyN9IIvbBwor4J+7CrwQ7Ix3KWS/COEaWoEK3q/g7FopYNHKjSDQ7LZ
UorjbIBfKvN5q19Kq1quJGMZZ/yXKmqb/QZW1Z5vf3FUmXxQTZWnsUONJoYFmOEqLhvw1ASDOnUw
8Zjgj+7qn5j3EnFzHVtPE604uH7/I5aTjBluwwKBfX97Au1J9yhKCXJAh3fhOQ/jE+Hj1xIhxy+L
+CgeUdz3Lgs64CtqoaCEISgREkXppq0U84wAs6qe+kB11vKLefg/lpqzvHKrreaGI/k5/uaXXhIf
3IBnYACnHb97+FcerGxRvs4LRKYCl/R3bCgO6hnPmzQoBoHOs3T2Mh2gDfbESV5UA1zGPEzPMmxA
cnFQVzqV0l2T0XtfyLsLeRH0+y74w08F8P3wOT63nNaPuj2u82P/WW==
